summaryrefslogtreecommitdiff
path: root/drivers/staging/comedi/drivers/amplc_pc236.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/staging/comedi/drivers/amplc_pc236.c')
-rw-r--r--drivers/staging/comedi/drivers/amplc_pc236.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/comedi/drivers/amplc_pc236.c b/drivers/staging/comedi/drivers/amplc_pc236.c
index ba91debae962..f9cc28317302 100644
--- a/drivers/staging/comedi/drivers/amplc_pc236.c
+++ b/drivers/staging/comedi/drivers/amplc_pc236.c
@@ -160,14 +160,14 @@ typedef struct {
#define devpriv ((pc236_private *)dev->private)
/*
* The comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains
* the device code.
*/
static int pc236_attach(struct comedi_device * dev, comedi_devconfig * it);
static int pc236_detach(struct comedi_device * dev);
-static comedi_driver driver_amplc_pc236 = {
+static struct comedi_driver driver_amplc_pc236 = {
driver_name:PC236_DRIVER_NAME,
module:THIS_MODULE,
attach:pc236_attach,
@@ -160,14 +160,14 @@ typedef struct {
#define devpriv ((pc236_private *)dev->private)
/*
- * The comedi_driver structure tells the Comedi core module
+ * The struct comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains